aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/core/hle/kernel/thread.h
diff options
context:
space:
mode:
authorGravatar bunnei <ericbunnie@gmail.com>2014-05-22 19:36:56 -0400
committerGravatar bunnei <ericbunnie@gmail.com>2014-05-22 19:36:56 -0400
commitb99ac2c3d67e2bcaa2c6eac220f1e93f4576c4fe (patch)
treedf05518971810d04f48a9e38505e487b5d29c323 /src/core/hle/kernel/thread.h
parent7c0b0060764e75738bc9d4417d0bfd510e54ae4e (diff)
thread: renamed "WaitCurThread" to "WaitCurrentThread", removed unused "reason" argument
Diffstat (limited to 'src/core/hle/kernel/thread.h')
-rw-r--r--src/core/hle/kernel/thread.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/core/hle/kernel/thread.h b/src/core/hle/kernel/thread.h
index d54f47aa..9628f165 100644
--- a/src/core/hle/kernel/thread.h
+++ b/src/core/hle/kernel/thread.h
@@ -53,8 +53,8 @@ Handle SetupMainThread(s32 priority, int stack_size=Kernel::DEFAULT_STACK_SIZE);
/// Reschedules to the next available thread (call after current thread is suspended)
void Reschedule();
-/// Puts a thread in the wait state for the given type/reason
-void WaitCurThread(WaitType wait_type, const char* reason);
+/// Puts the current thread in the wait state for the given type
+void WaitCurrentThread(WaitType wait_type);
/// Resumes a thread from waiting by marking it as "ready"
void ResumeThreadFromWait(Handle handle);